# Note: This package will be made available on GitHub
# (https://github.com/statnet/ergm.multi) by the end of 2020.
library(ergm.multi)
load("PMET.RData")

## Note: Several of these models (in particular, the more complex
## Lazega Lawyers models) require somewhat hefty computing resources
## and tuning to estimate reliably.

## Knecht Models
k12.m1<-ergm(K12p ~ L(~edges, ~friend & emosup) + L(~edges, ~friend & pracsup) + 
    L(~edges, ~emosup & pracsup) + L(~edges, ~friend & basis) + 
    L(~edges, ~emosup & basis) + L(~edges, ~pracsup & basis) + 
    L(~edges, ~basis & dislik) + L(~edges, ~emosup & lend) + 
    L(~edges, ~pracsup & lend) + L(~edges, ~basis & lend) + L(~edges, 
    ~friend & notlen) + L(~edges, ~emosup & notlen) + L(~edges, 
    ~pracsup & notlen) + L(~edges, ~basis & notlen) + L(~edges, 
    ~dislik & notlen) + L(~edges, ~friend & bully) + L(~edges, 
    ~pracsup & bully) + L(~edges, ~basis & bully) + L(~edges, 
    ~dislik & bully) + L(~edges, ~notlen & bully) + L(~edges, 
    ~friend) + L(~edges, ~emosup) + L(~edges, ~pracsup) + L(~edges, 
    ~basis) + L(~edges, ~lend) + L(~edges, ~notlen) + L(~edges, 
    ~dislik) + L(~edges, ~bully))

k12.m2<-ergm(K12p ~ CMBL(list(~friend, ~emosup, ~pracsup, ~basis, ~lend)) + 
    CMBL(list(~notlen, ~dislik, ~bully)) + L(~edges, ~friend) + 
    L(~edges, ~emosup) + L(~edges, ~pracsup) + L(~edges, ~basis) + 
    L(~edges, ~lend) + L(~edges, ~notlen) + L(~edges, ~dislik) + 
    L(~edges, ~bully))

k12.m3<-ergm(K12p ~ L(~edges, ~friend & emosup) + L(~edges, ~friend & pracsup) + 
    L(~edges, ~emosup & pracsup) + L(~edges, ~friend & basis) + 
    L(~edges, ~emosup & basis) + L(~edges, ~pracsup & basis) + 
    L(~edges, ~basis & dislik) + L(~edges, ~emosup & lend) + 
    L(~edges, ~pracsup & lend) + L(~edges, ~basis & lend) + L(~edges, 
    ~friend & notlen) + L(~edges, ~emosup & notlen) + L(~edges, 
    ~pracsup & notlen) + L(~edges, ~basis & notlen) + L(~edges, 
    ~dislik & notlen) + L(~edges, ~friend & bully) + L(~edges, 
    ~pracsup & bully) + L(~edges, ~basis & bully) + L(~edges, 
    ~dislik & bully) + L(~edges, ~notlen & bully) + L(~edges, 
    ~friend) + L(~edges, ~emosup) + L(~edges, ~pracsup) + L(~edges, 
    ~basis) + L(~edges, ~lend) + L(~edges, ~notlen) + L(~edges, 
    ~dislik) + L(~edges, ~bully) + L(~nodematch("sex") + absdiff("age") + 
    absdiff("siblings") + absdiff("money") + nodematch("actkiss"), 
    c(~friend, ~emosup, ~pracsup, ~basis, ~lend)) + L(~nodematch("sex") + 
    absdiff("age") + absdiff("siblings") + absdiff("money") + 
    nodematch("actkiss"), c(~notlen, ~dislik, ~bully)))

k12.m4<-ergm(K12p ~ CMBL(list(~friend, ~emosup, ~pracsup, ~basis, ~lend)) + 
    CMBL(list(~notlen, ~dislik, ~bully)) + L(~edges, ~friend) + 
    L(~edges, ~emosup) + L(~edges, ~pracsup) + L(~edges, ~basis) + 
    L(~edges, ~lend) + L(~edges, ~notlen) + L(~edges, ~dislik) + 
    L(~edges, ~bully) + L(~nodematch("sex") + absdiff("age") + 
    absdiff("siblings") + absdiff("money") + nodematch("actkiss"), 
    c(~friend, ~emosup, ~pracsup, ~basis, ~lend)) + L(~nodematch("sex") + 
    absdiff("age") + absdiff("siblings") + absdiff("money") + 
    nodematch("actkiss"), c(~notlen, ~dislik, ~bully)))

## Lazega Models
laz.m1<-ergm(LLazega ~ L(~edges + mutual + nodeifactor("gender") + nodeofactor("gender") + 
    nodematch("gender") + nodematch("office") + nodeifactor("practice") + 
    nodeofactor("practice") + nodematch("practice") + nodeicov("yrs_frm") + 
    nodeocov("yrs_frm") + absdiff("yrs_frm") + gwesp(fix = TRUE, 
    decay = 0.25) + nodeifactor("status") + nodeofactor("status") + 
    nodematch("status"), ~coworker) + L(~edges + mutual + nodeifactor("gender") + 
    nodeofactor("gender") + nodematch("gender") + nodematch("office") + 
    nodeifactor("practice") + nodeofactor("practice") + nodematch("practice") + 
    nodeicov("yrs_frm") + nodeocov("yrs_frm") + absdiff("yrs_frm") + 
    gwesp(fix = TRUE, decay = 0.25) + nodeifactor("status") + 
    nodeofactor("status") + nodematch("status"), ~friendship) + 
    L(~edges + mutual + nodeifactor("gender") + nodeofactor("gender") + 
        nodematch("gender") + nodematch("office") + nodeifactor("practice") + 
        nodeofactor("practice") + nodematch("practice") + nodeicov("yrs_frm") + 
        nodeocov("yrs_frm") + absdiff("yrs_frm") + gwesp(fix = TRUE, 
        decay = 0.25) + nodeifactor("status") + nodeofactor("status") + 
        nodematch("status"), ~advice))

laz.m2<-ergm(LLazega ~ L(~edges + mutual + nodeofactor("gender") + nodeifactor("gender") + 
    nodematch("gender") + nodematch("office") + nodeifactor("practice") + 
    nodeofactor("practice") + nodematch("practice") + nodeicov("yrs_frm") + 
    nodeocov("yrs_frm") + absdiff("yrs_frm") + gwesp(fix = TRUE, 
    decay = 0.25) + nodeifactor("status") + nodeofactor("status") + 
    nodematch("status"), ~coworker) + L(~edges + mutual + nodeofactor("gender") + 
    nodeifactor("gender") + nodematch("gender") + nodematch("office") + 
    nodeifactor("practice") + nodeofactor("practice") + nodematch("practice") + 
    nodeicov("yrs_frm") + nodeocov("yrs_frm") + absdiff("yrs_frm") + 
    gwesp(fix = TRUE, decay = 0.25) + nodeifactor("status") + 
    nodeofactor("status") + nodematch("status"), ~friendship) + 
    L(~edges + mutual + nodeofactor("gender") + nodeifactor("gender") + 
        nodematch("gender") + nodematch("office") + nodeifactor("practice") + 
        nodeofactor("practice") + nodematch("practice") + nodeicov("yrs_frm") + 
        nodeocov("yrs_frm") + absdiff("yrs_frm") + gwesp(fix = TRUE, 
        decay = 0.25) + nodeifactor("status") + nodeofactor("status") + 
        nodematch("status"), ~advice) + dgwespL(type = "OTP", 
    L.base = ~friendship, Ls.path = c(~coworker, ~advice), L.in_order = TRUE, 
    fix = TRUE, decay = 0.25, cutoff = 30) + L(~gwidegree(decay = 0.4, 
    fix = TRUE, cutoff = 50) + gwodegree(decay = 0.4, fix = TRUE, 
    cutoff = 50), ~.) + twostarL(Ls = c(~coworker, ~advice), 
    type = "path", distinct = TRUE))


laz.m3<-ergm(LLazega ~ L(~edges + mutual + nodeofactor("gender") + nodeifactor("gender") + 
    nodematch("gender") + nodematch("office") + nodeifactor("practice") + 
    nodeofactor("practice") + nodematch("practice") + nodeicov("yrs_frm") + 
    nodeocov("yrs_frm") + absdiff("yrs_frm") + gwesp(fix = TRUE, 
    decay = 0.25) + nodeifactor("status") + nodeofactor("status") + 
    nodematch("status"), ~coworker) + L(~edges + mutual + nodeofactor("gender") + 
    nodeifactor("gender") + nodematch("gender") + nodematch("office") + 
    nodeifactor("practice") + nodeofactor("practice") + nodematch("practice") + 
    nodeicov("yrs_frm") + nodeocov("yrs_frm") + absdiff("yrs_frm") + 
    gwesp(fix = TRUE, decay = 0.25) + nodeifactor("status") + 
    nodeofactor("status") + nodematch("status"), ~friendship) + 
    L(~edges + mutual + nodeofactor("gender") + nodeifactor("gender") + 
        nodematch("gender") + nodematch("office") + nodeifactor("practice") + 
        nodeofactor("practice") + nodematch("practice") + nodeicov("yrs_frm") + 
        nodeocov("yrs_frm") + absdiff("yrs_frm") + gwesp(fix = TRUE, 
        decay = 0.25) + nodeifactor("status") + nodeofactor("status") + 
        nodematch("status"), ~advice) + L(~edges + mutual, ~coworker & 
    friendship) + L(~edges + mutual, ~coworker & advice) + L(~edges + 
    mutual, ~friendship & advice) + mutualL(Ls = c(~coworker, 
    ~friendship)) + mutualL(Ls = c(~coworker, ~advice)) + mutualL(Ls = c(~friendship, 
    ~advice)) + dgwespL(type = "OTP", L.base = ~friendship, Ls.path = c(~coworker, 
    ~advice), L.in_order = TRUE, fix = TRUE, decay = 0.25, cutoff = 30) + 
    L(~gwidegree(decay = 0.4, fix = TRUE, cutoff = 50) + gwodegree(decay = 0.4, 
        fix = TRUE, cutoff = 50), ~.) + twostarL(Ls = c(~coworker, 
    ~advice), type = "path", distinct = TRUE))

laz.m4<-ergm(LLazega ~ L(~edges + mutual + nodeofactor("gender") + nodeifactor("gender") + 
    nodematch("gender") + nodematch("office") + nodeifactor("practice") + 
    nodeofactor("practice") + nodematch("practice") + nodeicov("yrs_frm") + 
    nodeocov("yrs_frm") + absdiff("yrs_frm") + dgwesp(fix = TRUE, 
    decay = 0.25, type = "OTP") + dgwesp(fix = TRUE, decay = 0.25, 
    type = "ITP") + nodeifactor("status") + nodeofactor("status") + 
    nodematch("status"), ~coworker) + L(~edges + mutual + nodeofactor("gender") + 
    nodeifactor("gender") + nodematch("gender") + nodematch("office") + 
    nodeifactor("practice") + nodeofactor("practice") + nodematch("practice") + 
    nodeicov("yrs_frm") + nodeocov("yrs_frm") + absdiff("yrs_frm") + 
    dgwesp(fix = TRUE, decay = 0.25, type = "OTP") + dgwesp(fix = TRUE, 
    decay = 0.25, type = "ITP") + nodeifactor("status") + nodeofactor("status") + 
    nodematch("status"), ~friendship) + L(~edges + mutual + nodeofactor("gender") + 
    nodeifactor("gender") + nodematch("gender") + nodematch("office") + 
    nodeifactor("practice") + nodeofactor("practice") + nodematch("practice") + 
    nodeicov("yrs_frm") + nodeocov("yrs_frm") + absdiff("yrs_frm") + 
    dgwesp(fix = TRUE, decay = 0.25, type = "OTP") + dgwesp(fix = TRUE, 
    decay = 0.25, type = "ITP") + nodeifactor("status") + nodeofactor("status") + 
    nodematch("status"), ~advice) + L(~edges + mutual, ~coworker & 
    friendship) + L(~edges + mutual, ~coworker & advice) + L(~edges + 
    mutual, ~friendship & advice) + mutualL(Ls = c(~coworker, 
    ~friendship)) + mutualL(Ls = c(~coworker, ~advice)) + mutualL(Ls = c(~friendship, 
    ~advice)) + dgwespL(type = "OTP", L.base = ~friendship, Ls.path = c(~coworker, 
    ~advice), L.in_order = TRUE, fix = TRUE, decay = 0.25, cutoff = 30) + 
    L(~gwidegree(decay = 0.4, fix = TRUE, cutoff = 50) + gwodegree(decay = 0.4, 
        fix = TRUE, cutoff = 50), ~.) + twostarL(Ls = c(~coworker, 
    ~advice), type = "path", distinct = TRUE))
